@@ -3,6 +3,7 @@ package command
 import (
 	"bytes"
 	"context"
+	"errors"
 	"fmt"
 	"log"
 	"math"
@@ -13,6 +14,7 @@ import (
 
 	"github.com/hashicorp/hcl/v2"
 	packersdk "github.com/hashicorp/packer-plugin-sdk/packer"
+	"github.com/hashicorp/packer/internal/hcp/registry"
 	"github.com/hashicorp/packer/packer"
 	"golang.org/x/sync/semaphore"
 
@@ -88,38 +90,24 @@ func (c *BuildCommand) RunContext(buildCtx context.Context, cla *BuildArgs) int
 		return ret
 	}
 
-	diags = TrySetupHCP(packerStarter)
+	hcpRegistry, diags := registry.New(packerStarter)
 	ret = writeDiags(c.Ui, nil, diags)
 	if ret != 0 {
 		return ret
 	}
 
-	// This build currently enforces a 1:1 mapping that one publisher can be assigned to a single packer config file.
-	// It also requires that each config type implements this ConfiguredArtifactMetadataPublisher to return a configured bucket.
-	// TODO find an option that is not managed by a globally shared Publisher.
-	ArtifactMetadataPublisher, diags := packerStarter.ConfiguredArtifactMetadataPublisher()
-	if diags.HasErrors() {
-		return writeDiags(c.Ui, nil, diags)
+	err := hcpRegistry.PopulateIteration(buildCtx)
+	if err != nil {
+		return writeDiags(c.Ui, nil, hcl.Diagnostics{
+			&hcl.Diagnostic{
+				Summary:  "HCP: populating iteration failed",
+				Severity: hcl.DiagError,
+				Detail:   err.Error(),
+			},
+		})
 	}
 
-	// We need to create a bucket and an empty iteration before we retrieve builds
-	// so that we can add the iteration ID to the build's eval context
-	if ArtifactMetadataPublisher != nil {
-		if err := ArtifactMetadataPublisher.Initialize(buildCtx); err != nil {
-			diags := hcl.Diagnostics{
-				&hcl.Diagnostic{
-					Summary: "Failed to get HCP Packer Registry iteration",
-					Detail: fmt.Sprintf("Packer could not create an iteration or "+
-						"link the build to an existing iteration. Contact HCP Packer "+
-						"support for further assistance.\nError: %s", err),
-					Severity: hcl.DiagError,
-				},
-			}
-			return writeDiags(c.Ui, nil, diags)
-		}
-	}
-
-	builds, diags := packerStarter.GetBuilds(packer.GetBuildsOptions{
+	builds, hcpMap, diags := packerStarter.GetBuilds(packer.GetBuildsOptions{
 		Only:    cla.Only,
 		Except:  cla.Except,
 		Debug:   cla.Debug,
@@ -138,23 +126,6 @@ func (c *BuildCommand) RunContext(buildCtx context.Context, cla *BuildArgs) int
 		c.Ui.Say("Debug mode enabled. Builds will not be parallelized.")
 	}
 
-	// Now that builds have been retrieved, we can populate the iteration with
-	// the builds we expect to run.
-	if ArtifactMetadataPublisher != nil {
-		if err := ArtifactMetadataPublisher.PopulateIteration(buildCtx); err != nil {
-			diags := hcl.Diagnostics{
-				&hcl.Diagnostic{
-					Summary: "Failed to register builds to the HCP Packer registry iteration",
-					Detail: fmt.Sprintf("Packer could not register builds within your "+
-						"configuration to the iteration. Contact HCP Packer support "+
-						"for further assistance.\nError: %s", err),
-					Severity: hcl.DiagError,
-				},
-			}
-			return writeDiags(c.Ui, nil, diags)
-		}
-	}
-
 	// Compile all the UIs for the builds
 	colors := [5]packer.UiColor{
 		packer.UiColorGreen,
@@ -215,7 +186,7 @@ func (c *BuildCommand) RunContext(buildCtx context.Context, cla *BuildArgs) int
 		m map[string][]packersdk.Artifact
 	}{m: make(map[string][]packersdk.Artifact)}
 	// Get the builds we care about
-	var errors = struct {
+	var errs = struct {
 		sync.RWMutex
 		m map[string]error
 	}{m: make(map[string]error)}
@@ -231,9 +202,9 @@ func (c *BuildCommand) RunContext(buildCtx context.Context, cla *BuildArgs) int
 		ui := buildUis[b]
 		if err := limitParallel.Acquire(buildCtx, 1); err != nil {
 			ui.Error(fmt.Sprintf("Build '%s' failed to acquire semaphore: %s", name, err))
-			errors.Lock()
-			errors.m[name] = err
-			errors.Unlock()
+			errs.Lock()
+			errs.m[name] = err
+			errs.Unlock()
 			break
 		}
 		// Increment the waitgroup so we wait for this item to finish properly
@@ -248,6 +219,26 @@ func (c *BuildCommand) RunContext(buildCtx context.Context, cla *BuildArgs) int
 
 			defer limitParallel.Release(1)
 
+			err := hcpRegistry.StartBuild(buildCtx, hcpMap[name])
+			// Seems odd to require this error check here. Now that it is an error we can just exit with diag
+			if err != nil {
+				// If the build is already done, we skip without a warning
+				if errors.As(err, &registry.ErrBuildAlreadyDone{}) {
+					ui.Say(fmt.Sprintf("skipping already done build %q", name))
+					return
+				}
+				writeDiags(c.Ui, nil, hcl.Diagnostics{
+					&hcl.Diagnostic{
+						Summary: fmt.Sprintf(
+							"hcp: failed to start build %q",
+							name),
+						Severity: hcl.DiagError,
+						Detail:   err.Error(),
+					},
+				})
+				return
+			}
+
 			log.Printf("Starting build run: %s", name)
 			runArtifacts, err := b.Run(buildCtx, ui)
 
@@ -256,11 +247,28 @@ func (c *BuildCommand) RunContext(buildCtx context.Context, cla *BuildArgs) int
 			buildDuration := buildEnd.Sub(buildStart)
 			fmtBuildDuration := durafmt.Parse(buildDuration).LimitFirstN(2)
 
+			runArtifacts, hcperr := hcpRegistry.CompleteBuild(
+				buildCtx,
+				hcpMap[name],
+				runArtifacts,
+				err)
+			if hcperr != nil {
+				writeDiags(c.Ui, nil, hcl.Diagnostics{
+					&hcl.Diagnostic{
+						Summary: fmt.Sprintf(
+							"failed to complete HCP-enabled build %q",
+							name),
+						Severity: hcl.DiagError,
+						Detail:   hcperr.Error(),
+					},
+				})
+			}
+
 			if err != nil {
 				ui.Error(fmt.Sprintf("Build '%s' errored after %s: %s", name, fmtBuildDuration, err))
-				errors.Lock()
-				errors.m[name] = err
-				errors.Unlock()
+				errs.Lock()
+				errs.m[name] = err
+				errs.Unlock()
 			} else {
 				ui.Say(fmt.Sprintf("Build '%s' finished after %s.", name, fmtBuildDuration))
 				if runArtifacts != nil {
@@ -280,7 +288,6 @@ func (c *BuildCommand) RunContext(buildCtx context.Context, cla *BuildArgs) int
 			log.Printf("Parallelization disabled, waiting for build to finish: %s", b.Name())
 			wg.Wait()
 		}
-
 	}
 
 	// Wait for both the builds to complete and the interrupt handler,
@@ -299,11 +306,11 @@ func (c *BuildCommand) RunContext(buildCtx context.Context, cla *BuildArgs) int
 		return 1
 	}
 
-	if len(errors.m) > 0 {
-		c.Ui.Machine("error-count", strconv.FormatInt(int64(len(errors.m)), 10))
+	if len(errs.m) > 0 {
+		c.Ui.Machine("error-count", strconv.FormatInt(int64(len(errs.m)), 10))
 
 		c.Ui.Error("\n==> Some builds didn't complete successfully and had errors:")
-		for name, err := range errors.m {
+		for name, err := range errs.m {
 			// Create a UI for the machine readable stuff to be targeted
 			ui := &packer.TargetedUI{
 				Target: name,
@@ -366,7 +373,7 @@ func (c *BuildCommand) RunContext(buildCtx context.Context, cla *BuildArgs) int
 		c.Ui.Say("\n==> Builds finished but no artifacts were created.")
 	}
 
-	if len(errors.m) > 0 {
+	if len(errs.m) > 0 {
 		// If any errors occurred, exit with a non-zero exit status
 		ret = 1
 	}
@@ -393,7 +400,8 @@ Options:
   -parallel-builds=1            Number of builds to run in parallel. 1 disables parallelization. 0 means no limit (Default: 0)
   -timestamp-ui                 Enable prefixing of each ui output with an RFC3339 timestamp.
   -var 'key=value'              Variable for templates, can be used multiple times.
-  -var-file=path                JSON or HCL2 file containing user variables.
+  -var-file=path                JSON or HCL2 file containing user variables, can be used multiple times.
+  -warn-on-undeclared-var       Display warnings for user variable files containing undeclared variables.
 `
 
 	return strings.TrimSpace(helpText)
