@@ -73,6 +73,15 @@ func TestParse_build(t *testing.T) {
 			&PackerConfig{
 				CorePackerVersionString: lockedVersion,
 				Basedir:                 filepath.Join("testdata", "build"),
+				Sources: map[SourceRef]SourceBlock{
+					{
+						Type: "null",
+						Name: "test",
+					}: {
+						Type: "null",
+						Name: "test",
+					},
+				},
 				Builds: Builds{
 					&BuildBlock{
 						ProvisionerBlocks: []*ProvisionerBlock{
@@ -80,6 +89,14 @@ func TestParse_build(t *testing.T) {
 								PType: "nonexistent",
 							},
 						},
+						Sources: []SourceUseBlock{
+							{
+								SourceRef: SourceRef{
+									Type: "null",
+									Name: "test",
+								},
+							},
+						},
 					},
 				},
 			},
@@ -134,6 +151,15 @@ func TestParse_build(t *testing.T) {
 			&PackerConfig{
 				CorePackerVersionString: lockedVersion,
 				Basedir:                 filepath.Join("testdata", "build"),
+				Sources: map[SourceRef]SourceBlock{
+					{
+						Type: "null",
+						Name: "test",
+					}: {
+						Type: "null",
+						Name: "test",
+					},
+				},
 				Builds: Builds{
 					&BuildBlock{
 						PostProcessorsLists: [][]*PostProcessorBlock{
@@ -143,6 +169,14 @@ func TestParse_build(t *testing.T) {
 								},
 							},
 						},
+						Sources: []SourceUseBlock{
+							{
+								SourceRef: SourceRef{
+									Type: "null",
+									Name: "test",
+								},
+							},
+						},
 					},
 				},
 			},
