@@ -14,11 +14,11 @@ import (
 	"github.com/google/go-cmp/cmp"
 	multierror "github.com/hashicorp/go-multierror"
 	version "github.com/hashicorp/go-version"
-	"github.com/hashicorp/hcl/v2"
+	hcl "github.com/hashicorp/hcl/v2"
 	packersdk "github.com/hashicorp/packer-plugin-sdk/packer"
 	"github.com/hashicorp/packer-plugin-sdk/template"
 	"github.com/hashicorp/packer-plugin-sdk/template/interpolate"
-	packerregistry "github.com/hashicorp/packer/internal/registry"
+	plugingetter "github.com/hashicorp/packer/packer/plugin-getter"
 	packerversion "github.com/hashicorp/packer/version"
 )
 
@@ -27,8 +27,6 @@ import (
 type Core struct {
 	Template *template.Template
 
-	Bucket *packerregistry.Bucket
-
 	components ComponentFinder
 	variables  map[string]string
 	builds     map[string]*template.Builder
@@ -131,7 +129,20 @@ func NewCore(c *CoreConfig) *Core {
 	return core
 }
 
-func (core *Core) Initialize() error {
+func (c *Core) Initialize(_ InitializeOptions) hcl.Diagnostics {
+	err := c.initialize()
+	if err != nil {
+		return hcl.Diagnostics{
+			&hcl.Diagnostic{
+				Detail:   err.Error(),
+				Severity: hcl.DiagError,
+			},
+		}
+	}
+	return nil
+}
+
+func (core *Core) initialize() error {
 	if err := core.validate(); err != nil {
 		return err
 	}
@@ -155,9 +166,20 @@ func (core *Core) Initialize() error {
 
 		core.builds[v] = b
 	}
+
 	return nil
 }
 
+func (c *Core) PluginRequirements() (plugingetter.Requirements, hcl.Diagnostics) {
+	return nil, hcl.Diagnostics{
+		&hcl.Diagnostic{
+			Summary:  "Packer plugins currently only works with HCL2 configuration templates",
+			Detail:   "Please manually install plugins with the plugins command or use a HCL2 configuration that will do that for you.",
+			Severity: hcl.DiagError,
+		},
+	}
+}
+
 // BuildNames returns the builds that are available in this configured core.
 func (c *Core) BuildNames(only, except []string) []string {
 
@@ -246,9 +268,10 @@ func (c *Core) generateCoreBuildProvisioner(rawP *template.Provisioner, rawName
 
 // This is used for json templates to launch the build plugins.
 // They will be prepared via b.Prepare() later.
-func (c *Core) GetBuilds(opts GetBuildsOptions) ([]packersdk.Build, hcl.Diagnostics) {
+func (c *Core) GetBuilds(opts GetBuildsOptions) ([]packersdk.Build, map[string]string, hcl.Diagnostics) {
 	buildNames := c.BuildNames(opts.Only, opts.Except)
 	builds := []packersdk.Build{}
+	hcpTranslationMap := map[string]string{}
 	diags := hcl.Diagnostics{}
 	for _, n := range buildNames {
 		b, err := c.Build(n)
@@ -261,6 +284,8 @@ func (c *Core) GetBuilds(opts GetBuildsOptions) ([]packersdk.Build, hcl.Diagnost
 			continue
 		}
 
+		hcpTranslationMap[n] = HCPName(c.builds[n])
+
 		// Now that build plugin has been launched, call Prepare()
 		log.Printf("Preparing build: %s", b.Name())
 		b.SetDebug(opts.Debug)
@@ -290,7 +315,7 @@ func (c *Core) GetBuilds(opts GetBuildsOptions) ([]packersdk.Build, hcl.Diagnost
 			}
 		}
 	}
-	return builds, diags
+	return builds, hcpTranslationMap, diags
 }
 
 // HCPName is a helper to get a curated HCP name for a legacy JSON builder.
@@ -338,10 +363,6 @@ func (c *Core) Build(n string) (packersdk.Build, error) {
 	// rawName is the uninterpolated name that we use for various lookups
 	rawName := configBuilder.Name
 
-	// hcpName is the name we use for HCP, i.e. a concatenation of type+name
-	// if both are specified.
-	hcpName := HCPName(configBuilder)
-
 	// Setup the provisioners for this build
 	provisioners := make([]CoreBuildProvisioner, 0, len(c.Template.Provisioners))
 	for _, rawP := range c.Template.Provisioners {
@@ -399,14 +420,6 @@ func (c *Core) Build(n string) (packersdk.Build, error) {
 					"post-processor type not found: %s", rawP.Type)
 			}
 
-			if c.Bucket != nil {
-				postProcessor = &RegistryPostProcessor{
-					BuilderType:               hcpName,
-					ArtifactMetadataPublisher: c.Bucket,
-					PostProcessor:             postProcessor,
-				}
-			}
-
 			current = append(current, CoreBuildPostProcessor{
 				PostProcessor:     postProcessor,
 				PType:             rawP.Type,
@@ -423,27 +436,9 @@ func (c *Core) Build(n string) (packersdk.Build, error) {
 
 		postProcessors = append(postProcessors, current)
 	}
-	if c.Bucket != nil {
-		postProcessors = append(postProcessors, []CoreBuildPostProcessor{
-			{
-				PostProcessor: &RegistryPostProcessor{
-					BuilderType:               hcpName,
-					ArtifactMetadataPublisher: c.Bucket,
-				},
-			},
-		})
-	}
 
 	// TODO hooks one day
 
-	if c.Bucket != nil {
-		builder = &RegistryBuilder{
-			Name:                      hcpName,
-			ArtifactMetadataPublisher: c.Bucket,
-			Builder:                   builder,
-		}
-	}
-
 	// Return a structure that contains the plugins, their types, variables, and
 	// the raw builder config loaded from the json template
 	return &CoreBuild{
@@ -916,9 +911,3 @@ func (c *Core) init() error {
 
 	return nil
 }
-
-/// GetRegistryBucket returns a configured bucket that can be used for
-// publishing build image artifacts to some HCP Packer Registry.
-func (c *Core) GetRegistryBucket() *packerregistry.Bucket {
-	return c.Bucket
-}
