@@ -1,9 +1,8 @@
 package packer
 
 import (
-	"github.com/hashicorp/hcl/v2"
+	hcl "github.com/hashicorp/hcl/v2"
 	packersdk "github.com/hashicorp/packer-plugin-sdk/packer"
-	packerregistry "github.com/hashicorp/packer/internal/registry"
 	plugingetter "github.com/hashicorp/packer/packer/plugin-getter"
 )
 
@@ -22,7 +21,7 @@ type BuildGetter interface {
 	// GetBuilds return all possible builds for a config. It also starts all
 	// builders.
 	// TODO(azr): rename to builder starter ?
-	GetBuilds(GetBuildsOptions) ([]packersdk.Build, hcl.Diagnostics)
+	GetBuilds(GetBuildsOptions) ([]packersdk.Build, map[string]string, hcl.Diagnostics)
 }
 
 type Evaluator interface {
@@ -51,14 +50,6 @@ type Handler interface {
 	BuildGetter
 	ConfigFixer
 	ConfigInspector
-	HCPHandler
-}
-
-// The HCPHandler handles Packer things needed for communicating with a HCP Packer Registry.
-type HCPHandler interface {
-	// ConfiguredArtifactMetadataPublisher returns a configured Bucket that can be used to publish
-	// build artifacts to the said image bucket.
-	ConfiguredArtifactMetadataPublisher() (*packerregistry.Bucket, hcl.Diagnostics)
 }
 
 //go:generate enumer -type FixConfigMode
